// Copyright 2021 Tencent Inc. All rights reserved.
//
// 支付有礼活动对外API
//
// No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
//
// API version: 0.1.2

// Code generated by WechatPay APIv3 Generator based on [OpenAPI Generator](https://openapi-generator.tech); DO NOT EDIT.

package giftactivity_test

import (
	"context"
	"log"

	"git.nanodreamtech.com/sg/wechatpay-go/core"
	"git.nanodreamtech.com/sg/wechatpay-go/core/option"
	"git.nanodreamtech.com/sg/wechatpay-go/services/giftactivity"
	"git.nanodreamtech.com/sg/wechatpay-go/utils"
)

func ExampleActivityApiService_AddActivityMerchant() {
	var (
		mchID                      string = "190000****"                               // 商户号
		mchCertificateSerialNumber string = "3775************************************" // 商户证书序列号
		mchAPIv3Key                string = "2ab9****************************"         // 商户APIv3密钥
	)

	// 使用 utils 提供的函数从本地文件中加载商户私钥，商户私钥会用来生成请求的签名
	mchPrivateKey, err := utils.LoadPrivateKeyWithPath("/path/to/merchant/apiclient_key.pem")
	if err != nil {
		log.Printf("load merchant private key error:%s", err)
		return
	}

	ctx := context.Background()
	// 使用商户私钥等初始化 client，并使它具有自动定时获取微信支付平台证书的能力
	opts := []core.ClientOption{
		option.WithWechatPayAutoAuthCipher(mchID, mchCertificateSerialNumber, mchPrivateKey, mchAPIv3Key),
	}
	client, err := core.NewClient(ctx, opts...)
	if err != nil {
		log.Printf("new wechat pay client err:%s", err)
		return
	}

	svc := giftactivity.ActivityApiService{Client: client}
	resp, result, err := svc.AddActivityMerchant(ctx,
		giftactivity.AddActivityMerchantRequest{
			ActivityId:     core.String("126002309"),
			MerchantIdList: []string{"100123456"},
			AddRequestNo:   core.String("100002322019090134234sfdf"),
		},
	)

	if err != nil {
		// 处理错误
		log.Printf("call AddActivityMerchant err:%s", err)
	} else {
		// 处理返回结果
		log.Printf("status=%d resp=%s", result.Response.StatusCode, resp)
	}
}

func ExampleActivityApiService_CreateFullSendAct() {
	var (
		mchID                      string = "190000****"                               // 商户号
		mchCertificateSerialNumber string = "3775************************************" // 商户证书序列号
		mchAPIv3Key                string = "2ab9****************************"         // 商户APIv3密钥
	)

	// 使用 utils 提供的函数从本地文件中加载商户私钥，商户私钥会用来生成请求的签名
	mchPrivateKey, err := utils.LoadPrivateKeyWithPath("/path/to/merchant/apiclient_key.pem")
	if err != nil {
		log.Printf("load merchant private key error:%s", err)
		return
	}

	ctx := context.Background()
	// 使用商户私钥等初始化 client，并使它具有自动定时获取微信支付平台证书的能力
	opts := []core.ClientOption{
		option.WithWechatPayAutoAuthCipher(mchID, mchCertificateSerialNumber, mchPrivateKey, mchAPIv3Key),
	}
	client, err := core.NewClient(ctx, opts...)
	if err != nil {
		log.Printf("new wechat pay client err:%s", err)
		return
	}

	svc := giftactivity.ActivityApiService{Client: client}
	resp, result, err := svc.CreateFullSendAct(ctx,
		giftactivity.CreateFullSendActRequest{
			ActivityBaseInfo: &giftactivity.ActBaseInfo{
				ActivityName:        core.String("良品铺子回馈活动"),
				ActivitySecondTitle: core.String("海飞丝的券"),
				MerchantLogoUrl:     core.String("https://tool.oschina.net/regex.jpg"),
				BackgroundColor:     core.String("Color010"),
				BeginTime:           core.String("2015-05-20T13:29:35.120+08:00"),
				EndTime:             core.String("2015-05-20T13:29:35.120+08:00"),
				AvailablePeriods: &giftactivity.AvailablePeriod{
					AvailableTime: []giftactivity.AvailableTime{giftactivity.AvailableTime{
						BeginTime: core.String("2015-05-20T00:00:00.000+08:00"),
						EndTime:   core.String("2015-05-20T23:59:59.000+08:00"),
					}},
					AvailableDayTime: []giftactivity.AvailableDayTime{giftactivity.AvailableDayTime{
						BeginDayTime: core.String("110000"),
						EndDayTime:   core.String("135959"),
					}},
				},
				OutRequestNo:      core.String("100002322019090134234sfdf"),
				DeliveryPurpose:   giftactivity.DELIVERYPURPOSECATEGORY_OFF_LINE_PAY.Ptr(),
				MiniProgramsAppid: core.String("wx23232232323"),
				MiniProgramsPath:  core.String("/path/index/index"),
			},
			AwardSendRule: &giftactivity.FullSendRule{
				TransactionAmountMinimum: core.Int64(100),
				SendContent:              giftactivity.SENDCONTENTCATEGORY_SINGLE_COUPON.Ptr(),
				AwardType:                giftactivity.AWARDTYPE_BUSIFAVOR.Ptr(),
				AwardList: []giftactivity.AwardBaseInfo{giftactivity.AwardBaseInfo{
					StockId:          core.String("98065001"),
					OriginalImageUrl: core.String("https://tool.oschina.net/regex.jpg"),
					ThumbnailUrl:     core.String("https://tool.oschina.net/regex.jpg"),
				}},
				MerchantOption: giftactivity.SENDMERCHANTOPTION_IN_SEVICE_COUPON_MERCHANT.Ptr(),
				MerchantIdList: []string{"10000022"},
			},
			AdvancedSetting: &giftactivity.ActAdvancedSetting{
				DeliveryUserCategory: giftactivity.DELIVERYUSERCATEGORY_DELIVERY_ALL_PERSON.Ptr(),
				MerchantMemberAppid:  core.String("34567890"),
				PaymentMode: &giftactivity.PaymentMode{
					PaymentSceneList: []giftactivity.PaymentScene{giftactivity.PAYMENTSCENE_APP_SCENE},
				},
				PaymentMethodInformation: &giftactivity.PaymentMethodInfo{
					PaymentMethod:    giftactivity.PAYMENTMETHODCATEGORY_CFT.Ptr(),
					BankAbbreviation: core.String("AHRCUB_CREDIT"),
				},
				GoodsTags: []string{"xxx"},
			},
		},
	)

	if err != nil {
		// 处理错误
		log.Printf("call CreateFullSendAct err:%s", err)
	} else {
		// 处理返回结果
		log.Printf("status=%d resp=%s", result.Response.StatusCode, resp)
	}
}

func ExampleActivityApiService_DeleteActivityMerchant() {
	var (
		mchID                      string = "190000****"                               // 商户号
		mchCertificateSerialNumber string = "3775************************************" // 商户证书序列号
		mchAPIv3Key                string = "2ab9****************************"         // 商户APIv3密钥
	)

	// 使用 utils 提供的函数从本地文件中加载商户私钥，商户私钥会用来生成请求的签名
	mchPrivateKey, err := utils.LoadPrivateKeyWithPath("/path/to/merchant/apiclient_key.pem")
	if err != nil {
		log.Printf("load merchant private key error:%s", err)
		return
	}

	ctx := context.Background()
	// 使用商户私钥等初始化 client，并使它具有自动定时获取微信支付平台证书的能力
	opts := []core.ClientOption{
		option.WithWechatPayAutoAuthCipher(mchID, mchCertificateSerialNumber, mchPrivateKey, mchAPIv3Key),
	}
	client, err := core.NewClient(ctx, opts...)
	if err != nil {
		log.Printf("new wechat pay client err:%s", err)
		return
	}

	svc := giftactivity.ActivityApiService{Client: client}
	resp, result, err := svc.DeleteActivityMerchant(ctx,
		giftactivity.DeleteActivityMerchantRequest{
			ActivityId:      core.String("126002309"),
			MerchantIdList:  []string{"100123456"},
			DeleteRequestNo: core.String("100002322019090134234sfdf"),
		},
	)

	if err != nil {
		// 处理错误
		log.Printf("call DeleteActivityMerchant err:%s", err)
	} else {
		// 处理返回结果
		log.Printf("status=%d resp=%s", result.Response.StatusCode, resp)
	}
}

func ExampleActivityApiService_GetActDetail() {
	var (
		mchID                      string = "190000****"                               // 商户号
		mchCertificateSerialNumber string = "3775************************************" // 商户证书序列号
		mchAPIv3Key                string = "2ab9****************************"         // 商户APIv3密钥
	)

	// 使用 utils 提供的函数从本地文件中加载商户私钥，商户私钥会用来生成请求的签名
	mchPrivateKey, err := utils.LoadPrivateKeyWithPath("/path/to/merchant/apiclient_key.pem")
	if err != nil {
		log.Printf("load merchant private key error:%s", err)
		return
	}

	ctx := context.Background()
	// 使用商户私钥等初始化 client，并使它具有自动定时获取微信支付平台证书的能力
	opts := []core.ClientOption{
		option.WithWechatPayAutoAuthCipher(mchID, mchCertificateSerialNumber, mchPrivateKey, mchAPIv3Key),
	}
	client, err := core.NewClient(ctx, opts...)
	if err != nil {
		log.Printf("new wechat pay client err:%s", err)
		return
	}

	svc := giftactivity.ActivityApiService{Client: client}
	resp, result, err := svc.GetActDetail(ctx,
		giftactivity.GetActDetailRequest{
			ActivityId: core.String("10028001"),
		},
	)

	if err != nil {
		// 处理错误
		log.Printf("call GetActDetail err:%s", err)
	} else {
		// 处理返回结果
		log.Printf("status=%d resp=%s", result.Response.StatusCode, resp)
	}
}

func ExampleActivityApiService_ListActivities() {
	var (
		mchID                      string = "190000****"                               // 商户号
		mchCertificateSerialNumber string = "3775************************************" // 商户证书序列号
		mchAPIv3Key                string = "2ab9****************************"         // 商户APIv3密钥
	)

	// 使用 utils 提供的函数从本地文件中加载商户私钥，商户私钥会用来生成请求的签名
	mchPrivateKey, err := utils.LoadPrivateKeyWithPath("/path/to/merchant/apiclient_key.pem")
	if err != nil {
		log.Printf("load merchant private key error:%s", err)
		return
	}

	ctx := context.Background()
	// 使用商户私钥等初始化 client，并使它具有自动定时获取微信支付平台证书的能力
	opts := []core.ClientOption{
		option.WithWechatPayAutoAuthCipher(mchID, mchCertificateSerialNumber, mchPrivateKey, mchAPIv3Key),
	}
	client, err := core.NewClient(ctx, opts...)
	if err != nil {
		log.Printf("new wechat pay client err:%s", err)
		return
	}

	svc := giftactivity.ActivityApiService{Client: client}
	resp, result, err := svc.ListActivities(ctx,
		giftactivity.ListActivitiesRequest{
			Offset:         core.Int64(1),
			Limit:          core.Int64(20),
			ActivityName:   core.String("良品铺子回馈活动"),
			ActivityStatus: giftactivity.ACTSTATUS_ACT_STATUS_UNKNOWN.Ptr(),
			AwardType:      giftactivity.AWARDTYPE_BUSIFAVOR.Ptr(),
		},
	)

	if err != nil {
		// 处理错误
		log.Printf("call ListActivities err:%s", err)
	} else {
		// 处理返回结果
		log.Printf("status=%d resp=%s", result.Response.StatusCode, resp)
	}
}

func ExampleActivityApiService_ListActivityMerchant() {
	var (
		mchID                      string = "190000****"                               // 商户号
		mchCertificateSerialNumber string = "3775************************************" // 商户证书序列号
		mchAPIv3Key                string = "2ab9****************************"         // 商户APIv3密钥
	)

	// 使用 utils 提供的函数从本地文件中加载商户私钥，商户私钥会用来生成请求的签名
	mchPrivateKey, err := utils.LoadPrivateKeyWithPath("/path/to/merchant/apiclient_key.pem")
	if err != nil {
		log.Printf("load merchant private key error:%s", err)
		return
	}

	ctx := context.Background()
	// 使用商户私钥等初始化 client，并使它具有自动定时获取微信支付平台证书的能力
	opts := []core.ClientOption{
		option.WithWechatPayAutoAuthCipher(mchID, mchCertificateSerialNumber, mchPrivateKey, mchAPIv3Key),
	}
	client, err := core.NewClient(ctx, opts...)
	if err != nil {
		log.Printf("new wechat pay client err:%s", err)
		return
	}

	svc := giftactivity.ActivityApiService{Client: client}
	resp, result, err := svc.ListActivityMerchant(ctx,
		giftactivity.ListActivityMerchantRequest{
			ActivityId: core.String("126002309"),
			Offset:     core.Int64(1),
			Limit:      core.Int64(20),
		},
	)

	if err != nil {
		// 处理错误
		log.Printf("call ListActivityMerchant err:%s", err)
	} else {
		// 处理返回结果
		log.Printf("status=%d resp=%s", result.Response.StatusCode, resp)
	}
}

func ExampleActivityApiService_ListActivitySku() {
	var (
		mchID                      string = "190000****"                               // 商户号
		mchCertificateSerialNumber string = "3775************************************" // 商户证书序列号
		mchAPIv3Key                string = "2ab9****************************"         // 商户APIv3密钥
	)

	// 使用 utils 提供的函数从本地文件中加载商户私钥，商户私钥会用来生成请求的签名
	mchPrivateKey, err := utils.LoadPrivateKeyWithPath("/path/to/merchant/apiclient_key.pem")
	if err != nil {
		log.Printf("load merchant private key error:%s", err)
		return
	}

	ctx := context.Background()
	// 使用商户私钥等初始化 client，并使它具有自动定时获取微信支付平台证书的能力
	opts := []core.ClientOption{
		option.WithWechatPayAutoAuthCipher(mchID, mchCertificateSerialNumber, mchPrivateKey, mchAPIv3Key),
	}
	client, err := core.NewClient(ctx, opts...)
	if err != nil {
		log.Printf("new wechat pay client err:%s", err)
		return
	}

	svc := giftactivity.ActivityApiService{Client: client}
	resp, result, err := svc.ListActivitySku(ctx,
		giftactivity.ListActivitySkuRequest{
			ActivityId: core.String("10028001"),
			Offset:     core.Int64(1),
			Limit:      core.Int64(20),
		},
	)

	if err != nil {
		// 处理错误
		log.Printf("call ListActivitySku err:%s", err)
	} else {
		// 处理返回结果
		log.Printf("status=%d resp=%s", result.Response.StatusCode, resp)
	}
}

func ExampleActivityApiService_TerminateActivity() {
	var (
		mchID                      string = "190000****"                               // 商户号
		mchCertificateSerialNumber string = "3775************************************" // 商户证书序列号
		mchAPIv3Key                string = "2ab9****************************"         // 商户APIv3密钥
	)

	// 使用 utils 提供的函数从本地文件中加载商户私钥，商户私钥会用来生成请求的签名
	mchPrivateKey, err := utils.LoadPrivateKeyWithPath("/path/to/merchant/apiclient_key.pem")
	if err != nil {
		log.Printf("load merchant private key error:%s", err)
		return
	}

	ctx := context.Background()
	// 使用商户私钥等初始化 client，并使它具有自动定时获取微信支付平台证书的能力
	opts := []core.ClientOption{
		option.WithWechatPayAutoAuthCipher(mchID, mchCertificateSerialNumber, mchPrivateKey, mchAPIv3Key),
	}
	client, err := core.NewClient(ctx, opts...)
	if err != nil {
		log.Printf("new wechat pay client err:%s", err)
		return
	}

	svc := giftactivity.ActivityApiService{Client: client}
	resp, result, err := svc.TerminateActivity(ctx,
		giftactivity.TerminateActivityRequest{
			ActivityId: core.String("10028001"),
		},
	)

	if err != nil {
		// 处理错误
		log.Printf("call TerminateActivity err:%s", err)
	} else {
		// 处理返回结果
		log.Printf("status=%d resp=%s", result.Response.StatusCode, resp)
	}
}
